@@ -16,7 +16,9 @@ class QualityScoringEvent(Event):
     data: QualityScoringData
 
     VALID_TYPES: ClassVar[set] = {
-        EventType.QUALITY_SCORE_ASSIGNED
+        EventType.GOOD_QUALITY_SCORE_ASSIGNED,
+        EventType.BAD_QUALITY_SCORE_ASSIGNED,
+        EventType.NEUTRAL_QUALITY_SCORE_ASSIGNED
     }
 
     def model_dump_json(self, *args, **kwargs):
