@@ -36,7 +36,9 @@ class EventType(StrEnum):
     WORKFLOW_REMOVED = "chat.workflow.removed"
     WORKFLOW_STATUS_UPDATED = "chat.workflow.status_updated"
     #QUALITY SCORING
-    QUALITY_SCORE_ASSIGNED = "chat.quality_score.assigned"
+    GOOD_QUALITY_SCORE_ASSIGNED = "chat.quality_score.good"
+    BAD_QUALITY_SCORE_ASSIGNED = "chat.quality_score.bad"
+    NEUTRAL_QUALITY_SCORE_ASSIGNED = "chat.quality_score.neutral"
     #CONTINUOUS CONVERSATION
     CONTINUOUS_CONVERSATION_CREATED = "chat.continuous_conversation.created"
     CONTINUOUS_CONVERSATION_UPDATED = "chat.continuous_conversation.updated"
