@@ -155,4 +155,8 @@ class ErrorToMantainSafety(CustomException):
 
 class ResetAIAgentMessage(CustomException):
     def __init__(self, message="Raised to reset the agent and not answer the user", status_code=400, **context_data):
+        super().__init__(message, status_code=status_code, **context_data)
+
+class DatasetIDConversionsAPINotFound(NotFoundError):
+    def __init__(self, message="Dataset ID conversions API not found", status_code=404, **context_data):
         super().__init__(message, status_code=status_code, **context_data)
\ No newline at end of file
