@@ -13,6 +13,7 @@ from ....models.company.assets.contact_point import ContactPoint
 from ....models.analytics.events.base import Event
 from ....models.company.company_chats_snapshot import CompanyChatsSnapshot
 from ....models.company.assets.users.agent_chats_snapshot import AgentChatsSnapshot
+from ....models.company.assets.ai_agents.chatty_ai_agent import ChattyAIAgent
 from zoneinfo import ZoneInfo
 from typing import List
 from ....models.chat.highlight import Highlight
@@ -104,6 +105,35 @@ class EventFactory:
         events.append(event)
         return events
 
+    @staticmethod
+    def ai_agent_assignment_events(chat_with_assets: ChatWithAssets, company_info: EmpresaModel, trace_id: str,executor_type: ExecutorType, executor_id: StrObjectId, assigned_asset : AssignedAssetToChat, chatty_ai_agent:ChattyAIAgent, event_type: EventType, time: datetime, company_snapshot: Optional[CompanyChatsSnapshot] = None, agent_snapshot: Optional[AgentChatsSnapshot] = None) -> List[Event]:
+        events = []
+        base_data = EventFactory._create_base_customer_event_data(
+                                                                    chat_with_assets=chat_with_assets,
+                                                                    company_info=company_info,
+                                                                    executor_type=executor_type,
+                                                                    executor_id=executor_id,
+                                                                    company_snapshot=company_snapshot,
+                                                                    agent_snapshot=agent_snapshot
+                                                                  )
+        ai_agent_data = ChattyAIChatData(
+            **base_data.model_dump(),
+            chatty_ai_agent_id=chatty_ai_agent.id,
+            chatty_ai_agent=chatty_ai_agent,
+            time_to_chatty_ai_agent_seconds=int((assigned_asset.assigned_at - chat_with_assets.chat.created_at).total_seconds()) if event_type == EventType.AI_AGENT_ASSIGNED_TO_CHAT else None
+        )
+        event = ChattyAIChatEvent(
+            specversion=EventFactory.package_version(),
+            type=event_type,
+            time=time,
+            data=ai_agent_data,
+            source="chatty_api.webapp",
+            company_id=company_info.id,
+            trace_id=trace_id
+        )
+        events.append(event)
+        return events
+
     @staticmethod
     def tag_assignment_events(chat_with_assets: ChatWithAssets, company_info: EmpresaModel, trace_id: str,executor_type: ExecutorType, executor_id: StrObjectId, assigned_asset : AssignedAssetToChat, tag: Tag, event_type: EventType, time: datetime, company_snapshot: Optional[CompanyChatsSnapshot] = None, agent_snapshot: Optional[AgentChatsSnapshot] = None) -> List[Event]:
         events = []
